@@ -1,4 +1,4 @@
-import subjectHandler
+from nwborglab import subjectHandler
 import os
 import SAPOFTO
 import orgutils
